| Title: | Interface to 'episensr' for Sensitivity Analysis of Epidemiological Results |
|---|---|
| Description: | API for using 'episensr', Basic sensitivity analysis of the observed relative risks adjusting for unmeasured confounding and misclassification of the exposure/outcome, or both. See <https://cran.r-project.org/package=episensr>. |
| Authors: | Denis Haine [aut, cre] (ORCID: <https://orcid.org/0000-0002-6691-7335>) |
| Maintainer: | Denis Haine <[email protected]> |
| License: | GPL-2 |
| Version: | 2.0.0 |
| Built: | 2026-06-02 09:32:40 UTC |
| Source: | https://codeberg.org/dhaine/apisensr |
Runs the 'apisensr' Shiny application. This function does not return; interrupt R to stop the application (usually by pressing Ctrl+C or Esc).
run_app(...)run_app(...)
... |
Unused arguments. |
## Not run: run_app() ## End(Not run)## Not run: run_app() ## End(Not run)